@@ -25,50 +25,39 @@ class DescribeScdnDomainHttpCodeDataRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'scdn', '2017-11-15', 'DescribeScdnDomainHttpCodeData')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_LocationNameEn(self):
-		return self.get_query_params().get('LocationNameEn')
-
-	def set_LocationNameEn(self,LocationNameEn):
-		self.add_query_param('LocationNameEn',LocationNameEn)
-
-	def get_StartTime(self):
-		return self.get_query_params().get('StartTime')
-
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_IspNameEn(self):
-		return self.get_query_params().get('IspNameEn')
-
-	def set_IspNameEn(self,IspNameEn):
-		self.add_query_param('IspNameEn',IspNameEn)
-
-	def get_DomainName(self):
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_EndTime(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_EndTime(self): # String
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Interval(self):
+	def set_EndTime(self, EndTime):  # String
+		self.add_query_param('EndTime', EndTime)
+	def get_Interval(self): # String
 		return self.get_query_params().get('Interval')
 
-	def set_Interval(self,Interval):
-		self.add_query_param('Interval',Interval)
\ No newline at end of file
+	def set_Interval(self, Interval):  # String
+		self.add_query_param('Interval', Interval)
+	def get_LocationNameEn(self): # String
+		return self.get_query_params().get('LocationNameEn')
+
+	def set_LocationNameEn(self, LocationNameEn):  # String
+		self.add_query_param('LocationNameEn', LocationNameEn)
+	def get_StartTime(self): # String
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
+	def get_IspNameEn(self): # String
+		return self.get_query_params().get('IspNameEn')
+
+	def set_IspNameEn(self, IspNameEn):  # String
+		self.add_query_param('IspNameEn', IspNameEn)
