@@ -25,14 +25,9 @@ class DescribeScdnUserProtectInfoRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'scdn', '2017-11-15', 'DescribeScdnUserProtectInfo')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
